@@ -7,7 +7,7 @@
 # Author : Kim Seongjun (code@linkhubcorp.com)
 # Written : 2015-01-21
 # Contributor : Jeong Yohan (code@linkhubcorp.com)
-# Updated : 2021-04-21
+# Updated : 2022-09-29
 # Thanks for your interest.
 from io import BytesIO
 import json
@@ -377,6 +377,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         headers["Accept-Encoding"] = "gzip,deflate"
 
+        headers["User-Agent"] = "PYTHON POPBILL SDK"
+
         conn.request('GET', url, '', headers)
 
         response = conn.getresponse()
@@ -412,6 +414,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         headers["Accept-Encoding"] = "gzip,deflate"
 
+        headers["User-Agent"] = "PYTHON POPBILL SDK"
+
         conn.request('POST', url, postData, headers)
 
         response = conn.getresponse()
@@ -446,6 +450,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         headers["Accept-Encoding"] = "gzip,deflate"
 
+        headers["User-Agent"] = "PYTHON POPBILL SDK"
+
         conn.request('POST', url, postData, headers)
 
         response = conn.getresponse()
@@ -476,6 +482,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         headers["Accept-Encoding"] = "gzip,deflate"
 
+        headers["User-Agent"] = "PYTHON POPBILL SDK"
+
         # oraganize postData
         CRLF = '\r\n'
 
@@ -535,12 +543,14 @@ class CorpInfo(object):
     def __init__(self, **kwargs):
         self.__dict__ = kwargs
 
+class BizCheckInfo(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
 
 class File(object):
     def __init__(self, **kwargs):
         self.__dict__ = kwargs
 
-
 class PopbillException(Exception):
     def __init__(self, code, message):
         self.code = code
