@@ -6,10 +6,13 @@
 # http://www.popbill.com
 # Author : Jeong Yohan (code@linkhubcorp.com)
 # Written : 2015-03-20
-# Updated : 2021-12-22
+# Updated : 2022-08-03
 # Thanks for your interest.
 from .base import PopbillBase, PopbillException, File
-
+try:
+    from urllib import parse as parse
+except ImportError:
+    import urllib as parse
 
 class StatementService(PopbillBase):
     """ 팝빌 전자명세서 API Service Implementation. """
@@ -122,7 +125,7 @@ class StatementService(PopbillBase):
         if statement == None:
             raise PopbillException(-99999999, "전송할 전자명세서 정보가 입력되지 않았습니다.")
         if SendNum == None or SendNum == '':
-            raise PopbillException(-99999999, "팩스전송 발신번호가 올바르지 않았습니다.")
+            raise PopbillException(-99999999, "팩스전송 발신번호가 올바르지 않습니다.")
         if ReceiveNum == None or ReceiveNum == '':
             raise PopbillException(-99999999, "팩스전송 수신번호가 올바르지 않습니다.")
 
@@ -322,7 +325,7 @@ class StatementService(PopbillBase):
         uri += '&Order=' + Order
 
         if QString is not None:
-            uri += '&QString=' + QString
+            uri += '&QString=' + parse.quote(QString)
 
         return self._httpget(uri, CorpNum, UserID)
 
