@@ -7,11 +7,14 @@
 # Author : Kim Seongjun (code@linkhubcorp.com)
 # Written : 2015-01-21
 # Contributor : Jeong Yohan (code@linkhubcorp.com)
-# Updated : 2022-07-15
+# Updated : 2022-08-03
 # Thanks for your interest.
 from datetime import datetime
 from .base import PopbillBase, PopbillException, File
-
+try:
+    from urllib import parse as parse
+except ImportError:
+    import urllib as parse
 
 class TaxinvoiceService(PopbillBase):
     """ 팝빌 세금계산서 API Service Implementation."""
@@ -44,7 +47,7 @@ class TaxinvoiceService(PopbillBase):
             args
                 CorpNum : 회원 사업자번호
                 UserID : 팝빌 회원아이디
-                ToGo : 세금계산서 관련 기능 지정 문자. (SBOX,PBOX)
+                ToGo : 세금계산서 관련 기능 지정 문자. (TBOX,SWBOX,PWBOX,SBOX,PBOX,WRITE)
             return
                 30초 보안 토큰을 포함한 url
             raise
@@ -252,6 +255,24 @@ class TaxinvoiceService(PopbillBase):
 
         return self._httpget('/Taxinvoice/' + ItemKey+"?Detail", CorpNum)
 
+    def getXML(self, CorpNum, MgtKeyType, MgtKey):
+        """ 상세정보 확인 (XML)
+            args
+                CorpNum : 회원 사업자 번호
+                MgtKeyType : 문서번호 유형 one of ['SELL','BUY','TRUSTEE']
+                MgtKey : 파트너 문서번호
+            return
+                전자세금계산서 XML.
+            raise
+                PopbillException
+        """
+        if MgtKeyType not in self.__MgtKeyTypes:
+            raise PopbillException(-99999999, "문서번호 유형이 올바르지 않습니다.")
+        if MgtKey == None or MgtKey == "":
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
+
+        return self._httpget('/Taxinvoice/' + MgtKeyType + '/' + MgtKey + '?XML', CorpNum)
+
     def delete(self, CorpNum, MgtKeyType, MgtKey, UserID=None):
         """ 삭제
             args
@@ -953,7 +974,7 @@ class TaxinvoiceService(PopbillBase):
             uri += '&TaxRegIDType=' + TaxRegIDType
 
         if QString is not None:
-            uri += '&QString=' + QString
+            uri += '&QString=' + parse.quote(QString)
 
         if MgtKey is not None:
             uri += '&MgtKey=' + MgtKey
@@ -966,7 +987,7 @@ class TaxinvoiceService(PopbillBase):
 
         if CloseDownState is not None:
             uri += '&CloseDownState=' + ','.join(CloseDownState)
-
+        print(uri)
         return self._httpget(uri, CorpNum, UserID)
 
     def attachStatement(self, CorpNum, MgtKeyType, MgtKey, ItemCode, StmtMgtKey, UserID=None):
@@ -1124,6 +1145,18 @@ class TaxinvoiceService(PopbillBase):
         result = self._httpget('/?TG=CERT', CorpNum, UserID)
         return result.url
 
+    def getTaxCertInfo(self, CorpNum, UserID=None):
+        """공동인증서 정보확인
+            args
+                CorpNum : 회원 사업자번호
+                UserID  : 회원 팝빌아이디
+            return
+                공동인증서 정보.
+            raise
+                PopbillException
+        """
+        return self._httpget('/Taxinvoice/Certificate', CorpNum)
+
     def bulkSubmit(self, CorpNum, SubmitID, taxinvoiceList, forceIssue=False, UserID=None):
         """ 초대량 발행 접수
             args
